@@ -2,9 +2,6 @@ mod device;
 mod discover;
 mod error;
 
-pub use device::BluOS;
-pub use device::RepeatSetting;
-pub use device::State;
-pub use device::Status;
+pub use device::{BluOS, Playlist, PlaylistEntry, RepeatSetting, State, Status};
 pub use discover::{DiscoveredBluOSDevice, Discovery};
 pub use error::Error;
